@@ -22,6 +22,7 @@
 #include "_2ch/model_2ch.h"
 #include "_2ch/maru_2ch.h"
 
+
 extern char *URL_2CH_BOARDMENU;
 
 
@@ -29,9 +30,9 @@ extern nt_2ch_model_tp app_2ch_modelp;
 
 extern BOOL nt_2ch_model_init();
 extern BOOL nt_init_board_menu();
-extern BOOL nt_read_board(nt_2ch_model_tp modelp);
-extern BOOL nt_read_thread(nt_2ch_model_tp modelp);
-extern BOOL nt_write_msg(nt_2ch_model_tp modelp, 
+extern BOOL nt_read_board(nt_2ch_selected_item_tp selectp);
+extern BOOL nt_read_thread(nt_2ch_selected_item_tp selectp);
+extern BOOL nt_write_msg(nt_2ch_selected_item_tp selectp,
 			nt_write_data_tp writep, nt_cookie_tp cookiep, 
 			nt_maru_2ch_tp marup);
 
