@@ -18,10 +18,15 @@
 #ifndef _ENV_H_
 #define _ENV_H_
 
+#include "config.h"
+
 extern char LOG_PATH[];
 extern char USR_PATH[];
 extern char USR_COOKIE_PATH[];
 extern char USR_LOG_DB_PATH[];
+extern char USR_FAVORITE_BOARD_FILE_PATH[];
+extern char USR_FAVORITE_GRP_FILE_PATH[];
+extern char USR_FAVORITE_THREAD_FILE_PATH[];
 
 extern int FORCE_REFRESH;
 extern int THREAD_SORT_TYPE; 
@@ -73,6 +78,8 @@ extern char *MARU_PW;
 #define NT_COMMAND1_ID_2 "i"
 #define NT_COMMAND1_SEARCH_1 "search"
 #define NT_COMMAND1_SEARCH_2 "se"
+#define NT_COMMAND1_FAVORITE_1 "favorite"
+#define NT_COMMAND1_FAVORITE_2 "f"
 
 extern int set_option(int argc, char* argv[]);
 
