@@ -24,6 +24,8 @@
 #define NT_INFO_WRITE_MSG_SUCCESS (L"メッセージを書き込みました")
 #define NT_INFO_REFRESH_THREAD_SUCCESS (L"スレッドを更新しました")
 #define NT_INFO_REFRESH_BOARD_SUCCESS (L"板を更新しました")
+#define NT_INFO_ADD_FAVORITE_SUCCEEDED (L"お気に入りに追加しました")
+#define NT_INFO_DEL_FAVORITE_SUCCEEDED (L"お気に入りから削除しました")
 
 #define NT_TEXT_UNTRACKED_LOG_NAME (L"[DAT落] ")
 
