@@ -19,6 +19,15 @@
 #define _DISP_H_
 #include "ui/disp_win.h"
 #include "_2ch/search_2ch.h"
+#include "usr/favorite_t.h"
+
+#define DISP_STATE_MASK 0xff
+#define DISP_CMD_MASK 0xff00
+
+#define DISP_STATE(a) ((a)&DISP_STATE_MASK)
+#define DISP_CMD(a) ((a)&DISP_CMD_MASK)
+#define DISP_CLR_CMD(a) ((a)&=DISP_STATE_MASK)
+
 
 #define	DISP_STATE_ERROR			(-1)
 #define	DISP_STATE_BOARDMENU		1
@@ -28,7 +37,15 @@
 #define	DISP_STATE_HTML_RESULT		5
 #define	DISP_STATE_REFRESH			6
 #define	DISP_STATE_SEARCH_THREAD	7
+#define	DISP_STATE_FAVORITE			8
 
+#define DISP_CMD_ADD_FAVORITE (1*256)
+#define DISP_CMD_DEL_FAVORITE_BOARD (2*256)
+#define DISP_CMD_DEL_FAVORITE_GRP (3*256)
+#define DISP_CMD_DEL_FAVORITE_THREAD (4*256)
+#define DISP_CMD_SEL_FAVORITE_BOARD (5*256)
+#define DISP_CMD_SEL_FAVORITE_THREAD (6*256)
+#define DISP_CMD_UPDATE_FAVORITE (7*256)
 
 extern int disp_board_menu(nt_window_tp wp, 
 		nt_2ch_model_tp modelp, nt_2ch_selected_item_tp selectp);
@@ -39,11 +56,15 @@ extern int disp_reslist(nt_window_tp wp,
 extern int disp_thread_search(nt_window_tp wp, 
 		int prev_state, nt_link_tp thread_list, 
 		nt_searched_thread_tp *sel_threadpp);
+extern int disp_favorite(nt_window_tp wp, 
+		int prev_state, nt_favorite_handle h_favorite, 
+		void **result_hadle, nt_searched_thread_tp *sel_threadpp);
 extern void free_board_menu_ctx(void *ptr);
 extern void init_threadlist_ctx(void *ptr);
 extern void free_threadlist_ctx(void *ptr);
 extern void free_reslist_ctx(void *ptr);
 extern void free_search_thread_ctx(void *ptr);
+extern void free_favorite_ctx(void *ptr);
 extern BOOL disp_editor(nt_write_data_tp writep);
 extern int disp_html_result(nt_write_data_tp writep);
 
