@@ -18,9 +18,12 @@
 #ifndef _DB_H_ 
 #define _DB_H_ 
 
-#ifndef GDBM_COMPT 
+#include "env.h"
+
+#ifdef HAVE_NDBM_H 
+#define GDBM_COMPT
 #include <ndbm.h>
-#else
+#elif HAVE_GDBM_NDBM_H
 #include <gdbm-ndbm.h>
 #endif
 
