@@ -40,6 +40,7 @@
 #define NT_CMD_TREE 3
 #define NT_CMD_ID 4
 #define NT_CMD_SEARCH_THREAD 5
+#define NT_CMD_FAVORITE 6
 
 typedef struct tag_ctx_reslist_t *ctx_reslist_tp;
 typedef struct tag_ctx_reslist_t
@@ -399,6 +400,8 @@ int disp_reslist(nt_window_tp wp, nt_2ch_selected_item_tp selectp,
 		switch(cmd){
 		case NT_CMD_SEARCH_THREAD:
 			return DISP_STATE_SEARCH_THREAD;
+		case NT_CMD_FAVORITE:
+			return DISP_STATE_FAVORITE;
 		case NT_CMD_WRITE:
 			return state;
 		case NT_CMD_JMP_NEW:
@@ -882,6 +885,11 @@ static int parse_cmd1(const char *param, int *statep, const char **end)
 		0 == strncmp(NT_COMMAND1_SEARCH_2,param,
 			strlen(NT_COMMAND1_SEARCH_2))){
 		return NT_CMD_SEARCH_THREAD;
+	}else if(0 == strncmp(NT_COMMAND1_FAVORITE_1,param,
+			strlen(NT_COMMAND1_FAVORITE_1)) ||
+		0 == strncmp(NT_COMMAND1_FAVORITE_2,param,
+			strlen(NT_COMMAND1_FAVORITE_2))){
+		return NT_CMD_FAVORITE;
 	}
 	return NT_CMD_NONE;
 }
