@@ -28,7 +28,7 @@
 
 
 
-int nt_add_wch(WINDOW *w, wchar_t wc, attr_t attr)
+int nt_add_wch(WINDOW *w, const wchar_t wc, attr_t attr)
 {
 	cchar_t	c;
 
@@ -44,7 +44,7 @@ int nt_add_wch(WINDOW *w, wchar_t wc, attr_t attr)
 }
 
 
-int nt_add_wstr(WINDOW *w, wchar_t *wc, attr_t attr)
+int nt_add_wstr(WINDOW *w, const wchar_t *wc, attr_t attr)
 {
 	int ret;
 	assert(wc);
@@ -54,7 +54,7 @@ int nt_add_wstr(WINDOW *w, wchar_t *wc, attr_t attr)
 	return ret;
 }
 
-int nt_add_wnch(WINDOW *w, wchar_t wc, attr_t attr, size_t colmns)
+int nt_add_wnch(WINDOW *w, const wchar_t wc, attr_t attr, size_t colmns)
 {
 	int i, delta;
 	cchar_t c;
@@ -78,7 +78,7 @@ int nt_add_wnch(WINDOW *w, wchar_t wc, attr_t attr, size_t colmns)
 	return i / delta;
 }
 
-int nt_add_wnstr(WINDOW *w, wchar_t *wc, attr_t attr, size_t colmns)
+int nt_add_wnstr(WINDOW *w, const wchar_t *wc, attr_t attr, size_t colmns)
 {
 	int i, col, len;
 	cchar_t c;
@@ -128,7 +128,7 @@ int nt_get_column_length(const wchar_t *wc)
 }
 
 
-int nt_get_wc_count_within_colmns(wchar_t *wc, size_t colmns)
+int nt_get_wc_count_within_colmns(const wchar_t *wc, size_t colmns)
 {
 	int len;
 	int col = 0;
